@@ -1,7 +1,9 @@
+'use strict'
+
 var http = require('http')
-  , assert = require('assert')
-  , request = require('../index')
-  ;
+var assert = require('assert')
+var request = require('../index')
+var tape = require('tape')
 
 var server = http.createServer(function (req, resp) {
   resp.statusCode = 200
@@ -26,21 +28,34 @@ var server = http.createServer(function (req, resp) {
   }
   if (req.url === '/proxy') {
     assert.equal(req.method, 'PUT')
-    return req.pipe(request('http://localhost:8080/put')).pipe(resp)
+    req.pipe(request(server.url + '/put')).pipe(resp)
+    return
   }
-
   if (req.url === '/test') {
-    return request('http://localhost:8080/get').pipe(request.put('http://localhost:8080/proxy')).pipe(resp)
+    request(server.url + '/get').pipe(request.put(server.url + '/proxy')).pipe(resp)
+    return
   }
   throw new Error('Unknown url', req.url)
-}).listen(8080, function () {
-  request('http://localhost:8080/test', function (e, resp, body) {
-    if (e) throw e
-    if (resp.statusCode !== 200) throw new Error('statusCode not 200 ' + resp.statusCode)
-    assert.equal(body, 'success')
-    server.close()
+})
+
+tape('setup', function (t) {
+  server.listen(0, function () {
+    server.url = 'http://localhost:' + this.address().port
+    t.end()
   })
 })
 
+tape('chained one-line proxying', function (t) {
+  request(server.url + '/test', function (err, res, body) {
+    t.equal(err, null)
+    t.equal(res.statusCode, 200)
+    t.equal(body, 'success')
+    t.end()
+  })
+})
 
-
+tape('cleanup', function (t) {
+  server.close(function () {
+    t.end()
+  })
+})
